[][src]Struct bdf::chunks::HashLookupTable

pub struct HashLookupTable {
    pub entries: HashMap<u32, HashEntry>,
}

Fields

entries: HashMap<u32, HashEntry>

Methods

impl HashLookupTable[src]

pub fn new(entries: HashMap<u32, HashEntry>) -> Self[src]

Creates a new hash lookup table

pub fn get_entry(&self, name: &String) -> Option<(&u32, &HashEntry)>[src]

Returns an entry by the name of the hash function

pub fn serialize(&self) -> Vec<u8>[src]

Serializes the lookup table into a vector of bytes