[−][src]Struct bdf::chunks::GenericChunk
Fields
length: u32data: Vec<u8>crc: u32Methods
impl GenericChunk[src]
pub fn serialize(&mut self) -> Vec<u8>[src]
Serializes the chunk to a vector of bytes
pub fn data_entries(
&mut self,
lookup_table: &HashLookupTable
) -> Result<Vec<DataEntry>, Error>[src]
&mut self,
lookup_table: &HashLookupTable
) -> Result<Vec<DataEntry>, Error>
Returns the data entries of the chunk
pub fn from_data_entries(
entries: &Vec<DataEntry>,
lookup_table: &HashLookupTable
) -> GenericChunk[src]
entries: &Vec<DataEntry>,
lookup_table: &HashLookupTable
) -> GenericChunk
Constructs the chunk from a Vec of Data entries and a hash lookup table
pub fn compress(&mut self, level: u32) -> Result<(), Error>[src]
Compresses the data of the chunk using lzma with a level of 6
pub fn decompress(&mut self) -> Result<(), Error>[src]
Decompresses the data of the chunk with lzma